@@ -13,11 +13,14 @@ from colorama import *
 from web import *
 from PyQt5.Qt import PYQT_VERSION_STR
 from PyQt5.QtCore import QT_VERSION_STR
+from downloader import *
+import os
+os.system('"J:\py3.9\python.exe"')
 
 init(autoreset=True)
 
 
-Ui_MainWindow,_ = loadUiType('downloader.ui')
+#Ui_MainWindow,_ = loadUiType('downloader.ui')
 
 
 
@@ -237,7 +240,7 @@ if __name__ == '__main__':
     sys.exit(app.exec_())
 else:
     print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
-    run('v1.0.5')
+    run('1.0.7')
 
 
 
